# Generated by roxygen2: do not edit by hand

export(fuzzystring_anti_join)
export(fuzzystring_full_join)
export(fuzzystring_inner_join)
export(fuzzystring_join)
export(fuzzystring_left_join)
export(fuzzystring_right_join)
export(fuzzystring_semi_join)
importFrom(Rcpp,evalCpp)
importFrom(data.table,":=")
importFrom(data.table,.I)
importFrom(data.table,.N)
importFrom(data.table,CJ)
importFrom(data.table,as.data.table)
importFrom(data.table,copy)
importFrom(data.table,dcast)
importFrom(data.table,is.data.table)
importFrom(data.table,melt)
importFrom(data.table,rbindlist)
importFrom(data.table,setnames)
importFrom(data.table,setorder)
importFrom(stats,as.formula)
useDynLib(fuzzystring, .registration = TRUE)
