# Generated by using Rcpp::compileAttributes() -> do not edit by hand
# Generator token: 10BE3573-1514-4C36-9D1C-5A225CD40393

bind_by_rowid_cpp <- function(x_dt, y_dt, x_idx, y_idx, overlap) {
    .Call(`_fuzzystring_bind_by_rowid_cpp`, x_dt, y_dt, x_idx, y_idx, overlap)
}

bind_by_rowid_cpp_matches <- function(x_dt, y_dt, matches_dt, overlap) {
    .Call(`_fuzzystring_bind_by_rowid_cpp_matches`, x_dt, y_dt, matches_dt, overlap)
}

