if (getRversion() >= "2.15.1") {
  utils::globalVariables(
    c(
      ".",
      ".I",
      ".N",
      ":=",
      "rowid",
      "key",
      "name",
      "newname",
      "..by2",
      "..extra_cols",
      "N",
      ".dummy",
      "as.formula",
      "_fuzzystring_bind_by_rowid_cpp",
      "_fuzzystring_bind_by_rowid_cpp_matches",
      "grp",
      "nchars",
      "value"
    )
  )
}
